==> huaweicloudsdkdds-3.0.19b0-py3-none-any.whl: huaweicloudsdkdds/v3/model/resize_instance_volume_option.py <==
# coding: utf-8

import pprint
import re

import six





class ResizeInstanceVolumeOption:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'group_id': 'str',
        'size': 'int'
    }

    attribute_map = {
        'group_id': 'group_id',
        'size': 'size'
    }

    def __init__(self, group_id=None, size=None):
        """ResizeInstanceVolumeOption - a model defined in huaweicloud sdk"""
        
        

        self._group_id = None
        self._size = None
        self.discriminator = None

        if group_id is not None:
            self.group_id = group_id
        self.size = size

    @property
    def group_id(self):
        """Gets the group_id of this ResizeInstanceVolumeOption.

        角色组ID。 - 对于集群实例，该参数为shard组ID。 - 对于副本集实例，不传该参数。 - 对于副本集和单节点实例，不传该参数。

        :return: The group_id of this ResizeInstanceVolumeOption.
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this ResizeInstanceVolumeOption.

        角色组ID。 - 对于集群实例，该参数为shard组ID。 - 对于副本集实例，不传该参数。 - 对于副本集和单节点实例，不传该参数。

        :param group_id: The group_id of this ResizeInstanceVolumeOption.
        :type: str
        """
        self._group_id = group_id

    @property
    def size(self):
        """Gets the size of this ResizeInstanceVolumeOption.

        待扩容到的磁盘容量。取值为10的整数倍，并且大于当前磁盘容量。 - 对于集群实例，表示扩容到的单个shard组的磁盘容量。取值范围：10GB~2000GB。 - 对于副本集实例，表示扩容到的实例的磁盘容量，取值范围：10GB~2000GB。 - 对于单节点实例，表示扩容到的实例的磁盘容量，取值范围：10GB~1000GB。

        :return: The size of this ResizeInstanceVolumeOption.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ResizeInstanceVolumeOption.

        待扩容到的磁盘容量。取值为10的整数倍，并且大于当前磁盘容量。 - 对于集群实例，表示扩容到的单个shard组的磁盘容量。取值范围：10GB~2000GB。 - 对于副本集实例，表示扩容到的实例的磁盘容量，取值范围：10GB~2000GB。 - 对于单节点实例，表示扩容到的实例的磁盘容量，取值范围：10GB~1000GB。

        :param size: The size of this ResizeInstanceVolumeOption.
        :type: int
        """
        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResizeInstanceVolumeOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdds-3.0.30rc0-py3-none-any.whl: huaweicloudsdkdds/v3/model/resize_instance_volume_option.py <==
# coding: utf-8

import pprint
import re

import six





class ResizeInstanceVolumeOption:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'group_id': 'str',
        'size': 'int'
    }

    attribute_map = {
        'group_id': 'group_id',
        'size': 'size'
    }

    def __init__(self, group_id=None, size=None):
        """ResizeInstanceVolumeOption - a model defined in huaweicloud sdk"""
        
        

        self._group_id = None
        self._size = None
        self.discriminator = None

        if group_id is not None:
            self.group_id = group_id
        self.size = size

    @property
    def group_id(self):
        """Gets the group_id of this ResizeInstanceVolumeOption.

        角色组ID。 - 对于集群实例，该参数为shard组ID。 - 对于副本集和单节点实例，不传该参数。

        :return: The group_id of this ResizeInstanceVolumeOption.
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this ResizeInstanceVolumeOption.

        角色组ID。 - 对于集群实例，该参数为shard组ID。 - 对于副本集和单节点实例，不传该参数。

        :param group_id: The group_id of this ResizeInstanceVolumeOption.
        :type: str
        """
        self._group_id = group_id

    @property
    def size(self):
        """Gets the size of this ResizeInstanceVolumeOption.

        待扩容到的磁盘容量。取值为10的整数倍，并且大于当前磁盘容量。 - 对于集群实例，表示扩容到的单个shard组的磁盘容量。取值范围：10GB~2000GB。 - 对于副本集实例，表示扩容到的实例的磁盘容量，取值范围：10GB~2000GB。 - 对于单节点实例，表示扩容到的实例的磁盘容量，取值范围：10GB~1000GB。

        :return: The size of this ResizeInstanceVolumeOption.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ResizeInstanceVolumeOption.

        待扩容到的磁盘容量。取值为10的整数倍，并且大于当前磁盘容量。 - 对于集群实例，表示扩容到的单个shard组的磁盘容量。取值范围：10GB~2000GB。 - 对于副本集实例，表示扩容到的实例的磁盘容量，取值范围：10GB~2000GB。 - 对于单节点实例，表示扩容到的实例的磁盘容量，取值范围：10GB~1000GB。

        :param size: The size of this ResizeInstanceVolumeOption.
        :type: int
        """
        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResizeInstanceVolumeOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
